@@ -71,8 +71,8 @@ public:
 
     void load();
 
-    void classBegin() Q_DECL_OVERRIDE;
-    void componentComplete() Q_DECL_OVERRIDE;
+    void classBegin() override;
+    void componentComplete() override;
 
     QVariantList asPoints() const;
     int count() const;
