@@ -23,6 +23,7 @@
 #include <QLayout>
 #include <QPushButton>
 #include <QFile>
+#include <QTextStream>
 #include <QTreeWidgetItem>
 #include <QTreeWidget>
 #include <QVBoxLayout>
@@ -57,7 +58,7 @@ int my_reset_handler(raw1394handle_t handle, unsigned int) {
 K_PLUGIN_FACTORY(View1394Factory, registerPlugin<View1394>();)
 
 View1394::View1394(QWidget *parent, const QVariantList &) :
-	KCModule(parent), m_insideRescanBus(false) {
+	KCModule(parent), m_insideRescanBus(false), m_ouiDb(nullptr) {
 	setQuickHelp(i18n("<qt>Here you can see some information about "
 		"your IEEE 1394 configuration. "
 		"The meaning of the columns:"
@@ -76,7 +77,6 @@ View1394::View1394(QWidget *parent, const QVariantList &) :
 		"</ul></qt>"
 		));
 
-	m_ouiDb=new OuiDb();
 	QVBoxLayout *box=new QVBoxLayout(this);
 	box->setContentsMargins(0, 0, 0, 0);
 	m_view=new View1394Widget(this);
@@ -254,7 +254,7 @@ void View1394::rescanBus() {
 				}
 				
 				QStringList nodeContents;
-				nodeContents << nodeStr << guidStr << local << irmStr << cmStr << isStr << bmStr << pmStr << accStr << speedStr << m_ouiDb->vendor(guid);
+				nodeContents << nodeStr << guidStr << local << irmStr << cmStr << isStr << bmStr << pmStr << accStr << speedStr << ouiDb()->vendor(guid);
 				
 				new QTreeWidgetItem(card, nodeContents);
 			}
@@ -270,10 +270,51 @@ void View1394::generateBusReset() {
 		raw1394_reset_bus(*it);
 }
 
+OuiDb *View1394::ouiDb() {
+	if (m_ouiDb==nullptr)
+		m_ouiDb=new OuiDb();
+	return m_ouiDb;
+}
+
 OuiDb::OuiDb() {
-	QString filename=QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kcmview1394/oui.db"));
-	if (filename.isEmpty())
+	const char *paths[]={
+		"/var/lib/ieee-data/oui.txt", /* Debian, ieee-data with updates */
+		"/usr/share/ieee-data/oui.txt", /* Debian, plain ieee-data */
+		"/usr/share/hwdata/oui.txt", /* hwdata */
+		nullptr
+	};
+	QString filename;
+	for (int i=0; paths[i]; ++i) {
+		if (QFile::exists(QLatin1String(paths[i]))) {
+			filename=QLatin1String(paths[i]);
+			loadFromOuiTxt(filename);
+			break;
+		}
+	}
+	if (!filename.isEmpty())
 		return;
+
+	filename=QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kcmview1394/oui.db"));
+	if (!filename.isEmpty())
+		loadFromCustomOuiDb(filename);
+}
+
+void OuiDb::loadFromOuiTxt(const QString &filename) {
+	QFile f(filename);
+	if (!f.open(QIODevice::ReadOnly | QIODevice::Text))
+		return;
+
+	QTextStream ts(&f);
+	ts.setCodec("UTF-8");
+	while (!ts.atEnd()) {
+		const QString line = ts.readLine();
+		if (line.isEmpty() || !line.contains(QLatin1String("(base 16)")))
+			continue;
+		m_vendorIds.insert(line.section(QLatin1Char(' '), 0, 0), line.section(QLatin1Char('\t'), 1, -1, QString::SectionSkipEmpty).trimmed());
+	}
+}
+
+void OuiDb::loadFromCustomOuiDb(const QString &filename) {
 	QFile f(filename);
 	if (!f.open(QIODevice::ReadOnly))
 		return;
